==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/FlowEndpointsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.FlowEndpointsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The flow endpoints configuration.
 * @property accessEndpointIpAddresses The access endpoint ip address.
 * @property outgoingIpAddresses The outgoing ip address.
 */
public data class FlowEndpointsArgs(
    public val accessEndpointIpAddresses: Output<List<IpAddressArgs>>? = null,
    public val outgoingIpAddresses: Output<List<IpAddressArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.FlowEndpointsArgs> {
    override fun toJava(): com.pulumi.azurenative.logic.inputs.FlowEndpointsArgs =
        com.pulumi.azurenative.logic.inputs.FlowEndpointsArgs.builder()
            .accessEndpointIpAddresses(
                accessEndpointIpAddresses?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .outgoingIpAddresses(
                outgoingIpAddresses?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [FlowEndpointsArgs].
 */
@PulumiTagMarker
public class FlowEndpointsArgsBuilder internal constructor() {
    private var accessEndpointIpAddresses: Output<List<IpAddressArgs>>? = null

    private var outgoingIpAddresses: Output<List<IpAddressArgs>>? = null

    /**
     * @param value The access endpoint ip address.
     */
    @JvmName("gktofohhobomskry")
    public suspend fun accessEndpointIpAddresses(`value`: Output<List<IpAddressArgs>>) {
        this.accessEndpointIpAddresses = value
    }

    @JvmName("xbbvetueogaapuar")
    public suspend fun accessEndpointIpAddresses(vararg values: Output<IpAddressArgs>) {
        this.accessEndpointIpAddresses = Output.all(values.asList())
    }

    /**
     * @param values The access endpoint ip address.
     */
    @JvmName("mlomwefitqeaeolt")
    public suspend fun accessEndpointIpAddresses(values: List<Output<IpAddressArgs>>) {
        this.accessEndpointIpAddresses = Output.all(values)
    }

    /**
     * @param value The outgoing ip address.
     */
    @JvmName("ahbhdquxsingsrbi")
    public suspend fun outgoingIpAddresses(`value`: Output<List<IpAddressArgs>>) {
        this.outgoingIpAddresses = value
    }

    @JvmName("gymremcmfiqtqjrl")
    public suspend fun outgoingIpAddresses(vararg values: Output<IpAddressArgs>) {
        this.outgoingIpAddresses = Output.all(values.asList())
    }

    /**
     * @param values The outgoing ip address.
     */
    @JvmName("kyykonapawiyxirg")
    public suspend fun outgoingIpAddresses(values: List<Output<IpAddressArgs>>) {
        this.outgoingIpAddresses = Output.all(values)
    }

    /**
     * @param value The access endpoint ip address.
     */
    @JvmName("wfydfkqlnbkonjck")
    public suspend fun accessEndpointIpAddresses(`value`: List<IpAddressArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.accessEndpointIpAddresses = mapped
    }

    /**
     * @param argument The access endpoint ip address.
     */
    @JvmName("iveeyeybyuebpuxn")
    public suspend
    fun accessEndpointIpAddresses(argument: List<suspend IpAddressArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { IpAddressArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.accessEndpointIpAddresses = mapped
    }

    /**
     * @param argument The access endpoint ip address.
     */
    @JvmName("kxalafijkevkyxjj")
    public suspend fun accessEndpointIpAddresses(
        vararg
        argument: suspend IpAddressArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map { IpAddressArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.accessEndpointIpAddresses = mapped
    }

    /**
     * @param argument The access endpoint ip address.
     */
    @JvmName("ylekbevjxihjvmis")
    public suspend fun accessEndpointIpAddresses(argument: suspend IpAddressArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IpAddressArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.accessEndpointIpAddresses = mapped
    }

    /**
     * @param values The access endpoint ip address.
     */
    @JvmName("ntxutkomxqeuptmu")
    public suspend fun accessEndpointIpAddresses(vararg values: IpAddressArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.accessEndpointIpAddresses = mapped
    }

    /**
     * @param value The outgoing ip address.
     */
    @JvmName("kpwfmusjsfqbfkqf")
    public suspend fun outgoingIpAddresses(`value`: List<IpAddressArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.outgoingIpAddresses = mapped
    }

    /**
     * @param argument The outgoing ip address.
     */
    @JvmName("hhutbtjejmvjusvv")
    public suspend fun outgoingIpAddresses(argument: List<suspend IpAddressArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { IpAddressArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.outgoingIpAddresses = mapped
    }

    /**
     * @param argument The outgoing ip address.
     */
    @JvmName("egkfdufhtqvussla")
    public suspend fun outgoingIpAddresses(vararg argument: suspend IpAddressArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { IpAddressArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.outgoingIpAddresses = mapped
    }

    /**
     * @param argument The outgoing ip address.
     */
    @JvmName("xvowwkgajrdcnqnb")
    public suspend fun outgoingIpAddresses(argument: suspend IpAddressArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IpAddressArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.outgoingIpAddresses = mapped
    }

    /**
     * @param values The outgoing ip address.
     */
    @JvmName("jqlwfuxfhfxprtbh")
    public suspend fun outgoingIpAddresses(vararg values: IpAddressArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.outgoingIpAddresses = mapped
    }

    internal fun build(): FlowEndpointsArgs = FlowEndpointsArgs(
        accessEndpointIpAddresses = accessEndpointIpAddresses,
        outgoingIpAddresses = outgoingIpAddresses,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/FlowEndpointsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.FlowEndpointsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The flow endpoints configuration.
 * @property accessEndpointIpAddresses The access endpoint ip address.
 * @property outgoingIpAddresses The outgoing ip address.
 */
public data class FlowEndpointsArgs(
    public val accessEndpointIpAddresses: Output<List<IpAddressArgs>>? = null,
    public val outgoingIpAddresses: Output<List<IpAddressArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.FlowEndpointsArgs> {
    override fun toJava(): com.pulumi.azurenative.logic.inputs.FlowEndpointsArgs =
        com.pulumi.azurenative.logic.inputs.FlowEndpointsArgs.builder()
            .accessEndpointIpAddresses(
                accessEndpointIpAddresses?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .outgoingIpAddresses(
                outgoingIpAddresses?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [FlowEndpointsArgs].
 */
@PulumiTagMarker
public class FlowEndpointsArgsBuilder internal constructor() {
    private var accessEndpointIpAddresses: Output<List<IpAddressArgs>>? = null

    private var outgoingIpAddresses: Output<List<IpAddressArgs>>? = null

    /**
     * @param value The access endpoint ip address.
     */
    @JvmName("vsepyfnqsicgeyki")
    public suspend fun accessEndpointIpAddresses(`value`: Output<List<IpAddressArgs>>) {
        this.accessEndpointIpAddresses = value
    }

    @JvmName("qohcjygbutlyhdtc")
    public suspend fun accessEndpointIpAddresses(vararg values: Output<IpAddressArgs>) {
        this.accessEndpointIpAddresses = Output.all(values.asList())
    }

    /**
     * @param values The access endpoint ip address.
     */
    @JvmName("xbbugpxioxwqjrqd")
    public suspend fun accessEndpointIpAddresses(values: List<Output<IpAddressArgs>>) {
        this.accessEndpointIpAddresses = Output.all(values)
    }

    /**
     * @param value The outgoing ip address.
     */
    @JvmName("kdpbvubhudvhkhla")
    public suspend fun outgoingIpAddresses(`value`: Output<List<IpAddressArgs>>) {
        this.outgoingIpAddresses = value
    }

    @JvmName("ydktsdhxhdkpqqef")
    public suspend fun outgoingIpAddresses(vararg values: Output<IpAddressArgs>) {
        this.outgoingIpAddresses = Output.all(values.asList())
    }

    /**
     * @param values The outgoing ip address.
     */
    @JvmName("desrnbrfxggaasox")
    public suspend fun outgoingIpAddresses(values: List<Output<IpAddressArgs>>) {
        this.outgoingIpAddresses = Output.all(values)
    }

    /**
     * @param value The access endpoint ip address.
     */
    @JvmName("xowiyvoxwxbmvloy")
    public suspend fun accessEndpointIpAddresses(`value`: List<IpAddressArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.accessEndpointIpAddresses = mapped
    }

    /**
     * @param argument The access endpoint ip address.
     */
    @JvmName("vlippjphpxhrsaiu")
    public suspend
    fun accessEndpointIpAddresses(argument: List<suspend IpAddressArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { IpAddressArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.accessEndpointIpAddresses = mapped
    }

    /**
     * @param argument The access endpoint ip address.
     */
    @JvmName("qsmwidtttnxljuww")
    public suspend fun accessEndpointIpAddresses(
        vararg
        argument: suspend IpAddressArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map { IpAddressArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.accessEndpointIpAddresses = mapped
    }

    /**
     * @param argument The access endpoint ip address.
     */
    @JvmName("jfnanpdkesxbgdnl")
    public suspend fun accessEndpointIpAddresses(argument: suspend IpAddressArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IpAddressArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.accessEndpointIpAddresses = mapped
    }

    /**
     * @param values The access endpoint ip address.
     */
    @JvmName("bltpenioukeiupwn")
    public suspend fun accessEndpointIpAddresses(vararg values: IpAddressArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.accessEndpointIpAddresses = mapped
    }

    /**
     * @param value The outgoing ip address.
     */
    @JvmName("ccrjstnwprwrcfkf")
    public suspend fun outgoingIpAddresses(`value`: List<IpAddressArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.outgoingIpAddresses = mapped
    }

    /**
     * @param argument The outgoing ip address.
     */
    @JvmName("kttpsubotinqxycg")
    public suspend fun outgoingIpAddresses(argument: List<suspend IpAddressArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { IpAddressArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.outgoingIpAddresses = mapped
    }

    /**
     * @param argument The outgoing ip address.
     */
    @JvmName("vkdttjfgstnrvure")
    public suspend fun outgoingIpAddresses(vararg argument: suspend IpAddressArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { IpAddressArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.outgoingIpAddresses = mapped
    }

    /**
     * @param argument The outgoing ip address.
     */
    @JvmName("qfpydwfprkpcriuo")
    public suspend fun outgoingIpAddresses(argument: suspend IpAddressArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IpAddressArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.outgoingIpAddresses = mapped
    }

    /**
     * @param values The outgoing ip address.
     */
    @JvmName("xuyfjyykvxryfocb")
    public suspend fun outgoingIpAddresses(vararg values: IpAddressArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.outgoingIpAddresses = mapped
    }

    internal fun build(): FlowEndpointsArgs = FlowEndpointsArgs(
        accessEndpointIpAddresses = accessEndpointIpAddresses,
        outgoingIpAddresses = outgoingIpAddresses,
    )
}
